#icons_banner .selected_resource{
	border-color: #00a7d0;
	border-radius: 10px ;
	box-shadow: 2px 2px 8px 2px #888888;
}

#icons_banner .tick {
   display: none;
   float: right;
   margin-right: 15px;
   margin-top: -5px;
}

#icons_banner div[class*="selected_resource"] > .tick {
   display: inline-block;
   color: green;
}
