ul.fancytree-container{
    border: none;
    position: relative;
}

span.fancytree-node {
    display: flex;
    flex-direction: row;
    align-content: center;
    align-items: center;
}

span.fancytree-title{
    width: 85%;
    white-space: normal;
    font-size: 14pt;
    font-family: 'Source Sans Pro', sans-serif;
}

span.fancytree-expander:hover{
    color: #37c0fb !important;
}