# Generated by Django 4.2.8 on 2024-03-13 21:06

from django.db import migrations


def forwards_func(apps, schema_editor):
    """Initialize the registry.
       Add the registry template, refinements, and resources.

    Returns:

    """
    from core_main_registry_app.discover import init_registry

    # Initialize registry
    init_registry()


class Migration(migrations.Migration):

    dependencies = [
        ("core_main_registry_app", "0001_initial"),
    ]

    operations = [
        migrations.RunPython(forwards_func, migrations.RunPython.noop)
    ]
